@@ -1,7 +1,7 @@
 from __future__ import print_function, unicode_literals
 from collections import namedtuple
 from itertools import cycle
-import mock
+from unittest import mock
 from zope.interface import alsoProvides
 from twisted.trial import unittest
 from twisted.internet.task import Clock, Cooperator
